/***
 *
 * NNPDF2.3QED Standalone Driver v1.0.0
 *
 * Stefano Carrazza for the NNPDF Collaboration
 * email: stefano.carrazza@mi.infn.it
 *
 * August 2013
 *
 * Usage:
 *
 *  NNPDFDriver *pdf = new NNPDFDriver("gridname.LHgrid");
 *
 *  pdf->xfxphoton(x,Q,fl); // -> returns double
 *  // with fl = [-6,7], LHAPDF format
 *    or
 *  pdf->xfxphoton(x,Q); // -> returns double*
 *  // with double* index from [0,13], always in the LHAPDF format
 *
 */

#pragma once

#include <iostream>
#include <string>
using std::string;

class NNPDFDriver {

 private:
  int fNFL;
  int fNX;
  int fNQ2;
  double ***fPDFGrid;
  double *fXGrid;
  double *fQ2Grid;

 public:
  NNPDFDriver(string const& gridfilename = "");
  ~NNPDFDriver();

  double xfxphoton(double const& x, double const& Q, int const& id);
  double* xfxphoton(double const& x, double const& Q);

 private:
  void readPDFSet(string const&);
  double* xfxevolve(double,double,int = -10);
  void lh_polin2(double*,double*,double**,int,int,
		 double,double,double&,double&);
  void lh_polint(double*,double*,int,double,double&,double&);
};
